summaryrefslogtreecommitdiff
path: root/MdePkg/Include/Protocol/DriverDiagnostics2.h
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Include/Protocol/DriverDiagnostics2.h')
-rw-r--r--MdePkg/Include/Protocol/DriverDiagnostics2.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/MdePkg/Include/Protocol/DriverDiagnostics2.h b/MdePkg/Include/Protocol/DriverDiagnostics2.h
index b56997d..0531223 100644
--- a/MdePkg/Include/Protocol/DriverDiagnostics2.h
+++ b/MdePkg/Include/Protocol/DriverDiagnostics2.h
@@ -45,7 +45,7 @@ typedef struct _EFI_DRIVER_DIAGNOSTICS2_PROTOCOL EFI_DRIVER_DIAGNOSTICS2_PROTOC
languages specified in SupportedLanguages.
The number of languages supported by a
driver is up to the driver writer. Language
- is specified in RFC 3066 language code format.
+ is specified in RFC 4646 language code format.
@param ErrorType A GUID that defines the format of the data returned in Buffer.
@param BufferSize The size, in bytes, of the data returned in Buffer.
@param Buffer A buffer that contains a Null-terminated Unicode string
@@ -100,7 +100,7 @@ EFI_STATUS
struct _EFI_DRIVER_DIAGNOSTICS2_PROTOCOL {
EFI_DRIVER_DIAGNOSTICS2_RUN_DIAGNOSTICS RunDiagnostics;
///
/// A Null-terminated ASCII string that contains one or more RFC 3066
/// language codes. This is the list of language codes that this protocol supports.
///
CHAR8 *SupportedLanguages;
@@ -100,7 +100,7 @@ EFI_STATUS
EFI_DRIVER_DIAGNOSTICS2_RUN_DIAGNOSTICS RunDiagnostics;
///
- /// A Null-terminated ASCII string that contains one or more RFC 3066
+ /// A Null-terminated ASCII string that contains one or more RFC 4646
/// language codes. This is the list of language codes that this protocol supports.
///